package plugin.sample.createcommunicationdiagram.action;

import java.awt.Point;
import java.io.File;
import java.util.*;

import com.vp.plugin.*;
import com.vp.plugin.action.*;
import com.vp.plugin.diagram.*;
import com.vp.plugin.diagram.connector.IMessageUIModel;
import com.vp.plugin.model.*;
import com.vp.plugin.model.factory.*;
import com.vp.plugin.model.property.IReferencedBy;

public class CreateActionController implements VPActionController {
	
	public void performAction(VPAction action) {
		createCommunicationDiagram();
	}
	public void update(VPAction arg0) {
	}
	
	
	public static void createCommunicationDiagram() {			
		
	
		// Creating Communication Diagram
		DiagramManager diagramManager = ApplicationManager.instance().getDiagramManager();
		IDiagramUIModel commDiagram = diagramManager.createDiagram(DiagramManager.DIAGRAM_TYPE_COMMUNICATION_DIAGRAM);

		// Creating Lifeline Models
		IModelElementFactory factory = IModelElementFactory.instance();
		
		IInteractionLifeLine orderController = factory.createInteractionLifeLine();
		orderController.setName("orderController");
		orderController.setBaseClassifier("OrderController"); // Setting a string  value as base classifier
		IInteractionLifeLine customerController = factory.createInteractionLifeLine();
		customerController.setName("customerController");

		// Create IClass as base classifier for customerControllerLifeline
		IClass customerControllerClass = factory.createClass();
		customerControllerClass.setName("CustomerController");
		
		// Assign customerControllerClass as base classifier  for customerControllerLifeline
		customerController.setBaseClassifier(customerControllerClass); 
						
		// Creating Lifeline Shapes
		IShapeUIModel orderControllerLifeline = (IShapeUIModel) diagramManager.createDiagramElement(commDiagram, orderController);	
		orderControllerLifeline.setBounds(100, 100, 180, 35);
		orderControllerLifeline.setRequestResetCaption(true); // to make sure the caption is correctly paint in diagram
		
		IShapeUIModel customerControllerLifeline = (IShapeUIModel) diagramManager.createDiagramElement(commDiagram, customerController);
		customerControllerLifeline.setBounds(500, 100, 220, 35);
		customerControllerLifeline.setRequestResetCaption(true);
		
		// Creating Link between Lifelines				
		IInteractionLifeLineLink link = factory.createInteractionLifeLineLink();
		link.setFrom(orderController);
		link.setTo(customerController);		
		IDiagramElement linkConnector = diagramManager.createConnector(commDiagram, link, orderControllerLifeline, customerControllerLifeline, null);		
		
		// Creating Message
		IMessage msg = factory.createMessage();
		link.addMessage(msg);
		msg.setFrom(link.getFrom());
		msg.setTo(link.getTo());
		msg.setName("retrieve Customer");
		msg.setSequenceNumber("1");
		
		// Creating Message Shape
		IShapeUIModel msgShape = (IShapeUIModel) diagramManager.createDiagramElement (commDiagram, msg);		
		msgShape.setSize ( 60, 60 );
		msgShape.setLocation ( 350, 80 );
		msgShape.getCaptionUIModel().setBounds(350, 80, 100, 30);
		linkConnector.addChild(msgShape);
		
		
		// Open the diagram		
		diagramManager.openDiagram(commDiagram);
		
		ApplicationManager.instance().getModelConvertionManager().exportDiagramAsImage(commDiagram, new File("d:\\a.png"), ExportDiagramAsImageOption.IMAGE_TYPE_JPG);		
					
	}
}